.. _weight-updater:

WeightUpdater
==============

.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.weight_updater.WeightUpdater gmmvi.optimization.gmmvi_modules.weight_updater.TrustRegionBasedWeightUpdater gmmvi.optimization.gmmvi_modules.weight_updater.DirectWeightUpdater
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_updater.WeightUpdater
   :members:
   :private-members:

.. _direct-weight:

DirectWeightUpdater
~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_updater.DirectWeightUpdater
   :members:
   :private-members:

.. _kl-weight:

TrustRegionBasedWeightUpdater
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.weight_updater.TrustRegionBasedWeightUpdater
   :members:
   :private-members:

.. toctree::
   :maxdepth: 2
   :glob: